==> react-molecule-select-1.39.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import { jsx as _jsx } from "react/jsx-runtime";
import { Children, createRef, cloneElement, useState, useRef, useEffect, useCallback } from 'react';
import cx from 'classnames';
import { moleculeDropdownListSizes as SIZES } from '@s-ui/react-molecule-dropdown-list';
import { inputSizes as SELECT_SIZES } from '@s-ui/react-atom-input';
import MoleculeSelectSingleSelection from './components/SingleSelection';
import MoleculeSelectMultipleSelection from './components/MultipleSelection';
import { withOpenToggle } from '@s-ui/hoc';
import { getTarget } from '@s-ui/js/lib/react';
import { getCurrentElementFocused } from '@s-ui/js/lib/dom';
var BASE_CLASS = "sui-MoleculeSelect";
var CLASS_FOCUS = BASE_CLASS + "--focus";
var CLASS_DISABLED = "is-disabled";
var SELECT_STATES = {
  ERROR: 'error',
  SUCCESS: 'success',
  ALERT: 'alert'
};
var ENABLED_KEYS = ['Enter', 'ArrowDown', 'ArrowUp'];

var getOptionData = function getOptionData(children) {
  var optionsData = {};
  Children.forEach(children, function (child) {
    var _child$props = child.props,
        children = _child$props.children,
        value = _child$props.value;
    optionsData[value] = children;
  });
  return optionsData;
};

var MoleculeSelect = function MoleculeSelect(props) {
  var _cx;

  var isOpen = props.isOpen,
      onToggle = props.onToggle,
      children = props.children,
      errorState = props.errorState,
      state = props.state,
      disabled = props.disabled,
      keysSelection = props.keysSelection,
      refMoleculeSelectFromProps = props.refMoleculeSelect;
  var refMoleculeSelect = useRef(refMoleculeSelectFromProps);
  var refsMoleculeSelectOptions = useRef([]);

  var _useState = useState(getOptionData(children)),
      optionsData = _useState[0],
      setOptionsData = _useState[1];

  var _useState2 = useState(false),
      focus = _useState2[0],
      setFocus = _useState2[1];

  var extendedChildren = Children.toArray(children).filter(Boolean).map(function (child, index) {
    refsMoleculeSelectOptions.current[index] = /*#__PURE__*/createRef();
    return /*#__PURE__*/cloneElement(child, {
      innerRef: refsMoleculeSelectOptions.current[index],
      onSelectKey: keysSelection
    });
  });
  var className = cx(BASE_CLASS, errorState && BASE_CLASS + "--" + SELECT_STATES.ERROR, errorState === false && BASE_CLASS + "--" + SELECT_STATES.SUCCESS, state && BASE_CLASS + "--" + state, (_cx = {}, _cx[CLASS_FOCUS] = focus, _cx[CLASS_DISABLED] = disabled, _cx));
  var closeList = useCallback(function (ev, _ref) {
    var _ref$isOutsideEvent = _ref.isOutsideEvent,
        isOutsideEvent = _ref$isOutsideEvent === void 0 ? false : _ref$isOutsideEvent;
    onToggle(ev, {
      isOpen: false
    });

    if (!isOutsideEvent) {
      ev.preventDefault();
      ev.stopPropagation();
    }
  }, [onToggle]);
  var handleOutsideClick = useCallback(function (ev) {
    if (disabled) return;

    if (refMoleculeSelect.current && !refMoleculeSelect.current.contains(ev.target)) {
      // outside click
      closeList(ev, {
        isOutsideEvent: true
      });
      setFocus(false);
    }
  }, [closeList, disabled]);
  useEffect(function () {
    setOptionsData(getOptionData(children));
    document.addEventListener('touchend', handleOutsideClick);
    document.addEventListener('mousedown', handleOutsideClick);
    return function () {
      document.removeEventListener('touchend', handleOutsideClick);
      document.removeEventListener('mousedown', handleOutsideClick);
    };
  }, [children, handleOutsideClick]);

  var focusFirstOption = function focusFirstOption(ev, _ref2) {
    var options = _ref2.options;
    options[0] && options[0].focus();
    ev.preventDefault();
    ev.stopPropagation();
  };

  var handleToggle = function handleToggle(ev) {
    onToggle(ev, {});
    ev.preventDefault();
    ev.stopPropagation();
  };

  var handleKeyDown = function handleKeyDown(ev) {
    ev.persist();
    var isEnabledKey = ENABLED_KEYS.includes(ev.key);
    var options = refsMoleculeSelectOptions.current.map(getTarget);
    var domSourceEvent = ev.target;
    var domMoleculeSelect = refMoleculeSelect.current;

    if (!isOpen && isEnabledKey) {
      domSourceEvent === domMoleculeSelect && handleToggle(ev);
    } else {
      var currentElementFocused = getCurrentElementFocused();
      var isSomeOptionFocused = [].concat(options).includes(currentElementFocused);
      var key = ev.key;
      if (key === 'Escape') closeList(ev, {
        isOutsideEvent: true
      });
      if (key === 'ArrowDown' && !isSomeOptionFocused) focusFirstOption(ev, {
        options: options
      });
      var optionToFocusOn = Array.from(options).find(function (option) {
        return option && option.innerText.charAt(0).toLowerCase() === key.toLowerCase();
      });
      optionToFocusOn && optionToFocusOn.focus();
    }
  };

  var handleFocusOut = function handleFocusOut(ev) {
    setFocus(false);
  };

  var handleFocusIn = function handleFocusIn() {
    !disabled && setFocus(true);
  };

  var multiselection = props.multiselection,
      propsFromProps = _objectWithoutPropertiesLoose(props, ["multiselection"]);

  return /*#__PURE__*/_jsx("div", {
    ref: refMoleculeSelect,
    tabIndex: "0",
    className: className,
    onKeyDown: handleKeyDown,
    onFocus: handleFocusIn,
    onBlur: handleFocusOut,
    children: multiselection ? /*#__PURE__*/_jsx(MoleculeSelectMultipleSelection, _extends({
      refMoleculeSelect: refMoleculeSelect,
      optionsData: optionsData
    }, propsFromProps, {
      children: extendedChildren
    })) : /*#__PURE__*/_jsx(MoleculeSelectSingleSelection, _extends({
      refMoleculeSelect: refMoleculeSelect,
      optionsData: optionsData
    }, propsFromProps, {
      children: extendedChildren
    }))
  });
};

MoleculeSelect.defaultProps = {
  disabled: false,
  keysSelection: [' ', 'Enter'],
  onChange: function onChange() {},
  onToggle: function onToggle() {},
  readOnly: false,
  selectSize: SELECT_SIZES.MEDIUM
};
var WithOpenToggleMoleculeSelect = withOpenToggle(MoleculeSelect);
WithOpenToggleMoleculeSelect.displayName = 'MoleculeSelect';
export default WithOpenToggleMoleculeSelect;
export { SIZES as moleculeSelectDropdownListSizes };
export { SELECT_SIZES as moleculeSelectSizes };
export { SELECT_STATES as moleculeSelectStates };

==> react-molecule-select-1.40.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { jsx as _jsx } from "react/jsx-runtime";
import { Children, createRef, cloneElement, useState, useRef, useEffect, useCallback } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { moleculeDropdownListSizes as SIZES } from '@s-ui/react-molecule-dropdown-list';
import { inputSizes as SELECT_SIZES } from '@s-ui/react-atom-input';
import MoleculeSelectSingleSelection from './components/SingleSelection';
import MoleculeSelectMultipleSelection from './components/MultipleSelection';
import { withOpenToggle } from '@s-ui/hoc';
import { getTarget } from '@s-ui/js/lib/react';
import { getCurrentElementFocused } from '@s-ui/js/lib/dom';
var BASE_CLASS = "sui-MoleculeSelect";
var CLASS_FOCUS = BASE_CLASS + "--focus";
var CLASS_DISABLED = "is-disabled";
var SELECT_STATES = {
  ERROR: 'error',
  SUCCESS: 'success',
  ALERT: 'alert'
};
var ENABLED_KEYS = ['Enter', 'ArrowDown', 'ArrowUp'];

var getOptionData = function getOptionData(children) {
  var optionsData = {};
  Children.forEach(children, function (child) {
    var _child$props = child.props,
        children = _child$props.children,
        value = _child$props.value;
    optionsData[value] = children;
  });
  return optionsData;
};

var MoleculeSelect = function MoleculeSelect(props) {
  var _cx;

  var isOpen = props.isOpen,
      onToggle = props.onToggle,
      children = props.children,
      errorState = props.errorState,
      state = props.state,
      disabled = props.disabled,
      keysSelection = props.keysSelection,
      multiselection = props.multiselection,
      refMoleculeSelectFromProps = props.refMoleculeSelect;
  var refMoleculeSelect = useRef(refMoleculeSelectFromProps);
  var refsMoleculeSelectOptions = useRef([]);

  var _useState = useState(getOptionData(children)),
      optionsData = _useState[0],
      setOptionsData = _useState[1];

  var _useState2 = useState(false),
      focus = _useState2[0],
      setFocus = _useState2[1];

  var extendedChildren = Children.toArray(children).filter(Boolean).map(function (child, index) {
    refsMoleculeSelectOptions.current[index] = /*#__PURE__*/createRef();
    return /*#__PURE__*/cloneElement(child, {
      innerRef: refsMoleculeSelectOptions.current[index],
      onSelectKey: keysSelection
    });
  });
  var className = cx(BASE_CLASS, errorState && BASE_CLASS + "--" + SELECT_STATES.ERROR, errorState === false && BASE_CLASS + "--" + SELECT_STATES.SUCCESS, state && BASE_CLASS + "--" + state, (_cx = {}, _cx[CLASS_FOCUS] = focus, _cx[CLASS_DISABLED] = disabled, _cx));
  var closeList = useCallback(function (ev, _ref) {
    var _ref$isOutsideEvent = _ref.isOutsideEvent,
        isOutsideEvent = _ref$isOutsideEvent === void 0 ? false : _ref$isOutsideEvent;
    onToggle(ev, {
      isOpen: false
    });

    if (!isOutsideEvent) {
      ev.preventDefault();
      ev.stopPropagation();
    }
  }, [onToggle]);
  var handleOutsideClick = useCallback(function (ev) {
    if (disabled) return;

    if (refMoleculeSelect.current && !refMoleculeSelect.current.contains(ev.target)) {
      // outside click
      closeList(ev, {
        isOutsideEvent: true
      });
      setFocus(false);
    }
  }, [closeList, disabled]);
  useEffect(function () {
    setOptionsData(getOptionData(children));
    document.addEventListener('touchend', handleOutsideClick);
    document.addEventListener('mousedown', handleOutsideClick);
    return function () {
      document.removeEventListener('touchend', handleOutsideClick);
      document.removeEventListener('mousedown', handleOutsideClick);
    };
  }, [children, handleOutsideClick]);

  var focusFirstOption = function focusFirstOption(ev, _ref2) {
    var options = _ref2.options;
    options[0] && options[0].focus();
    ev.preventDefault();
    ev.stopPropagation();
  };

  var handleToggle = function handleToggle(ev) {
    onToggle(ev, {});
    ev.preventDefault();
    ev.stopPropagation();
  };

  var handleKeyDown = function handleKeyDown(ev) {
    ev.persist();
    var isEnabledKey = ENABLED_KEYS.includes(ev.key);
    var options = refsMoleculeSelectOptions.current.map(getTarget);
    var domSourceEvent = ev.target;
    var domMoleculeSelect = refMoleculeSelect.current;

    if (!isOpen && isEnabledKey) {
      domSourceEvent === domMoleculeSelect && handleToggle(ev);
    } else {
      var currentElementFocused = getCurrentElementFocused();
      var isSomeOptionFocused = [].concat(options).includes(currentElementFocused);
      var key = ev.key;
      if (key === 'Escape') closeList(ev, {
        isOutsideEvent: true
      });
      if (key === 'ArrowDown' && !isSomeOptionFocused) focusFirstOption(ev, {
        options: options
      });
      var optionToFocusOn = Array.from(options).find(function (option) {
        return option && option.innerText.charAt(0).toLowerCase() === key.toLowerCase();
      });
      optionToFocusOn && optionToFocusOn.focus();
    }
  };

  var handleFocusOut = function handleFocusOut(ev) {
    setFocus(false);
  };

  var handleFocusIn = function handleFocusIn() {
    !disabled && setFocus(true);
  };

  return /*#__PURE__*/_jsx("div", {
    ref: refMoleculeSelect,
    tabIndex: "0",
    className: className,
    onKeyDown: handleKeyDown,
    onFocus: handleFocusIn,
    onBlur: handleFocusOut,
    children: multiselection ? /*#__PURE__*/_jsx(MoleculeSelectMultipleSelection, _extends({
      refMoleculeSelect: refMoleculeSelect,
      optionsData: optionsData
    }, props, {
      children: extendedChildren
    })) : /*#__PURE__*/_jsx(MoleculeSelectSingleSelection, _extends({
      refMoleculeSelect: refMoleculeSelect,
      optionsData: optionsData
    }, props, {
      children: extendedChildren
    }))
  });
};

MoleculeSelect.defaultProps = {
  disabled: false,
  keysSelection: [' ', 'Enter'],
  onChange: function onChange() {},
  onToggle: function onToggle() {},
  readOnly: false,
  selectSize: SELECT_SIZES.MEDIUM
};
var WithOpenToggleMoleculeSelect = withOpenToggle(MoleculeSelect);
WithOpenToggleMoleculeSelect.displayName = 'MoleculeSelect';
export default WithOpenToggleMoleculeSelect;
export { SIZES as moleculeSelectDropdownListSizes };
export { SELECT_SIZES as moleculeSelectSizes };
export { SELECT_STATES as moleculeSelectStates };
